# tree-sitter-bicep

[![Build Status](https://github.com/amaanq/tree-sitter-bicep/actions/workflows/ci.yml/badge.svg)](https://github.com/amaanq/tree-sitter-bicep/actions/workflows/ci.yml)
[![Discord](https://img.shields.io/discord/1063097320771698699?logo=discord)](https://discord.gg/w7nTvsVJhm)

Bicep grammar for [tree-sitter](https://github.com/tree-sitter/tree-sitter).

Adapted from [the official spec](https://docs.microsoft.com/en-us/azure/azure-resource-manager/bicep/overview)
